//+------------------------------------------------------------------+
//|                                                         Blur.mqh |
//|                              Copyright  2015, Vladimir Karputov |
//|                                           http://wmua.ru/slesar/ |
//+------------------------------------------------------------------+
#property copyright "Copyright  2015, Vladimir Karputov"
#property link      "http://wmua.ru/slesar/"
#property version   "1.0"
#property description "Blur image using the CGauss class"
#property script_show_inputs
#include "Gauss.mqh"
//--- input
input uint  radius_blur=4;             // blur radius
input int   shadow_shift=2;            // shadow shift
input color shadow_color=clrGray;      // shadow color
input uchar shadow_ransparence=160;    // shadow transparency
//+------------------------------------------------------------------+
//| Script program start function                                    |
//+------------------------------------------------------------------+
void OnStart()
  {
//--- variable width and height of the chart
   int ChartWidth=ChartWidthInPixels(0);
   int ChartHeight=ChartHeightInPixelsGet(0,0);
//---
   int total=128;
   int limit=MathMax(ChartWidth,ChartHeight);
   int x1,x2,x3,y1,y2,y3,r;
//--- create canvas
   CGauss MyCanvas;
   MyCanvas.RadiusBlur(radius_blur);
   MyCanvas.ShadowShift(shadow_shift);
   MyCanvas.SetShadowColor(ColorToARGB(shadow_color,shadow_ransparence));
   if(!MyCanvas.CreateBitmapLabel("MyBitmapLabel",0,0,ChartWidth,
      ChartHeight,COLOR_FORMAT_ARGB_NORMALIZE))
     {
      Print("Error creating canvas: ",GetLastError());
      return;
     }
   MyCanvas.Erase(ColorToARGB(clrNONE,0));
//--- draw horizontal/vertical lines
   for(int i=0;i<total && !IsStopped();i++)
     {
      x1=rand()%(ChartWidth/2);
      x2=rand()%(ChartWidth/2);
      y1=rand()%ChartHeight;
      y2=rand()%ChartHeight;
      if(i%2==0)
         MyCanvas.LineHorizontal(x1,x2,y1,RandomRGB());
      else
         MyCanvas.LineVertical(x1,y1,y2,RandomRGB());
      MyCanvas.Update();
      Sleep(21);
     }
//--- draw lines
   for(int i=0;i<total && !IsStopped();i++)
     {
      x1=rand()%(ChartWidth/2)+ChartWidth/2;
      x2=rand()%(ChartWidth/2)+ChartWidth/2;
      y1=rand()%ChartHeight;
      y2=rand()%ChartHeight;
      MyCanvas.Line(x1,y1,x2,y2,RandomRGB());
      MyCanvas.Update();
      Sleep(21);
     }
   Sleep(1500);
   MyCanvas.Erase(ColorToARGB(clrNONE,0));
   MyCanvas.Update();
   total/=2;
//--- draw polyline
   int x[],y[];
   ArrayResize(x,total);
   ArrayResize(y,total);
   for(int i=0;i<total && !IsStopped();i++)
     {
      x[i]=rand()%(ChartWidth/2);
      y[i]=rand()%ChartHeight;
     }
   MyCanvas.Polyline(x,y,RandomRGB());
   MyCanvas.Update();
//--- dray polygon
   for(int i=0;i<total && !IsStopped();i++)
     {
      x[i]=rand()%(ChartWidth/2)+ChartWidth/2;
      y[i]=rand()%ChartHeight;
     }
   MyCanvas.Polygon(x,y,RandomRGB());
   MyCanvas.Update();
   Sleep(1500);
   MyCanvas.Erase(ColorToARGB(clrNONE,0));
   MyCanvas.Update();
//--- draw rectangle/triangle
   for(int i=0;i<total && !IsStopped();i++)
     {
      x1=rand()%(ChartWidth/2);
      x2=rand()%(ChartWidth/2);
      x3=rand()%(ChartWidth/2);
      y1=rand()%ChartHeight;
      y2=rand()%ChartHeight;
      y3=rand()%ChartHeight;
      if(i%2==0)
         MyCanvas.Rectangle(x1,y1,x2,y2,RandomRGB());
      else
         MyCanvas.Triangle(x1,y1,x2,y2,x3,y3,RandomRGB());
      MyCanvas.Update();
      Sleep(21);
     }
//--- draw circle
   for(int i=0;i<total && !IsStopped();i++)
     {
      x1=rand()%(ChartWidth/2)+ChartWidth/2;
      y1=rand()%ChartHeight;
      r=rand()%(ChartHeight/2);
      MyCanvas.Circle(x1,y1,r,RandomRGB());
      MyCanvas.Update();
      Sleep(21);
     }
   Sleep(1500);
   MyCanvas.Erase(ColorToARGB(clrNONE,0));
   MyCanvas.Update();
//--- draw text
   MyCanvas.FontSizeSet(30);
   MyCanvas.TextOut(ChartWidth/3,ChartHeight/2,"Blur image using a CGauss class",ColorToARGB(clrRed,200),0);
   MyCanvas.Update();
   Sleep(10000);
//---
   MyCanvas.Destroy();
  }
//+------------------------------------------------------------------+
//| Chart property width                                             |
//+------------------------------------------------------------------+
int ChartWidthInPixels(const long chart_ID=0)
  {
//--- prepare the variable to get the property value
   long result=-1;
//--- reset the error value
   ResetLastError();
//--- receive the property value
   if(!ChartGetInteger(chart_ID,CHART_WIDTH_IN_PIXELS,0,result))
     {
      //--- display the error message in Experts journal
      Print(__FUNCTION__+", Error Code = ",GetLastError());
     }
//--- return the value of the chart property
   return((int)result);
  }
//+------------------------------------------------------------------+
//| Chart property height                                            |
//+------------------------------------------------------------------+
int ChartHeightInPixelsGet(const long chart_ID=0,const int sub_window=0)
  {
//--- prepare the variable to get the property value
   long result=-1;
//--- reset the error value
   ResetLastError();
//--- receive the property value
   if(!ChartGetInteger(chart_ID,CHART_HEIGHT_IN_PIXELS,sub_window,result))
     {
      //--- display the error message in Experts journal
      Print(__FUNCTION__+", Error Code = ",GetLastError());
     }
//--- return the value of the chart property
   return((int)result);
  }
//+------------------------------------------------------------------+
//| Random RGB color                                                 |
//+------------------------------------------------------------------+
uint RandomRGB(void)
  {
   return(ARGB(255,rand()%255,rand()%255,rand()%255));
  }
//+------------------------------------------------------------------+
